@@ -13,9 +13,7 @@ RADIOMIC_FEATURE_DIRNAME = "feature_data"
 RADIOMIC_FEATURE_FILENAME = "features.csv"
 
 # image&video extension supported by opencv
-IMAGE_EXTS = {"bmp", "dib", "jpeg", "jpg", "jpe", "jp2", "png", "webp", "pbm",
-              "pgm", "ppm", "pxm", "pnm", "pfm", "sr", "ras", "tiff", "tif",
-              "exr", "hdr", "pic"}
+IMAGE_EXTS = {"bmp", "dib", "jpeg", "jpg", "jpe", "jp2", "png", "tif", "tiff", "pic"}
 
 # from https://en.wikipedia.org/wiki/Video_file_format
 VIDEO_EXTS = {"mkv", "flv", "vob", "ogv", "ogg", "avi", "mov", "wmv", "rm",
