@@ -5,6 +5,7 @@ import math
 import json
 import argparse
 import logging
+import base64
 import tqdm
 import skvideo.io
 import numpy as np
@@ -15,6 +16,9 @@ import SimpleITK as sitk
 import PIL
 import PIL.Image
 import PIL.ImageDraw
+import string
+import tempfile
+import dicom2nifti
 
 from typing import List, Union, Tuple
 from multiprocessing import Manager, Pool
@@ -23,7 +27,8 @@ from radiomics.featureextractor import RadiomicsFeatureExtractor
 from raymics import DatasetType
 from raymics.constants import COL_LABEL, RADIOMIC_FEATURE_FILENAME
 from raymics.dataset import Dataset, LabeledDataset
-from raymics.utils import is_image, is_video, is_ndarray, is_labelme
+from raymics.utils import is_image, is_video, is_ndarray, is_labelme, \
+    is_dicom_folder, isBase64
 
 
 logging.basicConfig(format="%(asctime)s - %(levelname)s: %(message)s",
@@ -216,10 +221,19 @@ def extract_non_ts(data_paths: List[str], mask_paths: List[str],
     def read_non_ts(data_path, mask_path, label):
         # opencv image
         if is_image(data_path):
-            img = cv_img2sitk_image(data_path)
+            # img = cv_img2sitk_image(data_path)
+            img = sitk.ReadImage(data_path, sitk.sitkInt8)
         # numpy ndarray
         elif is_ndarray(data_path):
-            img = np.load(data_path)
+            arr = np.load(data_path)
+            img = sitk.GetImageFromArray(arr)
+        # dicom folder
+        elif is_dicom_folder(data_path):
+            with tempfile.TemporaryDirectory() as tmpdir:
+                tmp_img_path = \
+                    os.path.join(tmpdir, f"{string.ascii_lowercase}.nii.gz")
+                dicom2nifti.dicom_series_to_nifti(data_path, tmp_img_path)
+                img = sitk.ReadImage(tmp_img_path)
         # try to read image using SimpleITK
         else:
             img = sitk.ReadImage(data_path)
@@ -269,9 +283,8 @@ def extract_ts(data_path: str, mask_path: str, label: Union[int, float, int, Non
                         f"\nmask_path: {mask_path}")
 
 
-def extract(data_dir: str, result_dir: str, config_path: str,
-            processes: int = 2, cloud_run: bool = False,
-            progress = None) -> RadiomicsFeatureExtractor:
+def extract(data_dir: str, result_dir: str, config: Union[str, dict],
+            processes: int = 2, progress = None) -> RadiomicsFeatureExtractor:
     """
 
     Parameters
@@ -280,20 +293,15 @@ def extract(data_dir: str, result_dir: str, config_path: str,
         Directory of the raw dataset.
 
     result_dir : str
-        提取到的radiomics特征文件存放文件夹
+        Directory to save the feature files.
 
-    config_path : str
-        radiomics配置文件路径
+    config : str or dict
+        radiomics config of file(yaml or json) path or dict variable.
 
     processes : int
-        提取radiomics的进程数量
-
-    cloud_run : bool, default=False
-        云端执行
+        Processes to extracting radiomics features.
 
     """
-    assert os.path.exists(config_path), f"Config yaml file not found."
-
     dataset = LabeledDataset(root_dir=data_dir)
 
     if not os.path.exists(result_dir):
@@ -303,7 +311,7 @@ def extract(data_dir: str, result_dir: str, config_path: str,
         os.makedirs(result_dir)
 
     pool = Pool(processes=processes)
-    extractor = RadiomicsFeatureExtractor(config_path)
+    extractor = RadiomicsFeatureExtractor(config)
 
     data_type = DatasetType.TS if is_video(dataset[0][0]) else DatasetType.NON_TS
 
@@ -371,7 +379,7 @@ if __name__ == "__main__":
     parser = argparse.ArgumentParser()
 
     parser.add_argument(
-        "--data_dir",
+        "--dataset_dir",
         type=str,
         help="raw data dir"
     )
@@ -381,9 +389,9 @@ if __name__ == "__main__":
         help="Directory to save the features result."
     )
     parser.add_argument(
-        "--config_path",
+        "--config",
         type=str,
-        help="yaml file path."
+        help="yaml or json file path, or base64 string of json file."
     )
     parser.add_argument(
         "--cloud_run",
@@ -398,8 +406,16 @@ if __name__ == "__main__":
 
     args = parser.parse_args()
 
+    config = args.config
+    if isBase64(config):
+        config = json.loads(
+            base64.decodebytes(config.encode('utf-8')).decode('utf-8'))
+    else:
+        assert os.path.exists(config), f"config file not exists: {config}"
+
+    logging.info(f"config: {config}")
+
     extract(data_dir=args.data_dir,
-            config_path=args.config_path,
+            config=config,
             result_dir=args.result_dir,
-            cloud_run=args.cloud_run,
             processes=args.processes)
